# -*- coding: utf-8 -*-
"""
Get the activity difficulty ratings. These have been collected in a previous study
and are publicly available with this DOI: 10.4121/5198f299-9c7a-40f8-8206-c18df93ee2a0.
The file "ratings_data_anonym.csv" needs to be downloaded from that published dataset.

Required files:
    - Activity_Formulations_Competencies_Study_and_Mapping_to_Human_Inv_Activities.xlsx
    - ratings_data_anonym.csv
    
Output files:
    - Merged_Data_Difficulty_Ratings_Activities.xlsx

Author: Nele Albers
Date: April 2024
"""

import numpy as np
import pandas as pd


if __name__ == "__main__":

    # Number of preparatory activities in the difficulty ratings dataset
    NUM_ACTIVITIES = 44

    # Number of preparatory activities in our study (a subset of the 44)
    NUM_ACTIVITIES_HUMAN_INV = 37


    # Load difficulty ratings
    df_ratings = pd.read_csv("ratings_data_anonym.csv")


    # We need this file because not all activities from the difficulty dataset were used in our study
    df_activities = pd.read_excel("Activity_Formulations_Competencies_Study_and_Mapping_to_Human_Inv_Activities.xlsx")


    # All columns with difficulty ratings
    all_difficulty_ratings = [str(i) + "_Ease_1" for i in range(1, NUM_ACTIVITIES + 1)]


    # Columns we need to keep
    relevant_cols = all_difficulty_ratings.append("rand_id")
    df_ratings = df_ratings[all_difficulty_ratings]


    # Now we need to use only those ratings for the activities used in the human involvement study
    for a in range(1, NUM_ACTIVITIES + 1):
        a_index_human_inv = df_activities.iloc[a - 1]["Activity_Index_Human_Inv_Study"]
        if not np.isnan(a_index_human_inv):
            df_ratings = df_ratings.rename(columns={str(a) + "_Ease_1": str(int(a_index_human_inv)) + "_Ease"})


    # All columns with mapped difficulty ratings
    all_mapped_difficulty_ratings = [str(i) + "_Ease" for i in range(0, NUM_ACTIVITIES_HUMAN_INV)]


    # Columns we need to keep
    relevant_cols = all_mapped_difficulty_ratings.append("rand_id")
    df_ratings = df_ratings[all_mapped_difficulty_ratings]

    
    df_ratings.to_csv("Merged_Data_Difficulty_Ratings_Activities.csv", index=False)
