# -*- coding: utf-8 -*-
"""
Clean and anonymize the feedback reading confirmation data from Qualtrics.

Since we cannot provide the non-anonymized data, you cannot run this file yourself.

Required files:
    - Qualtrics_Exports/Human_Inv_Final_Human_Feedback_Confirmation_Final_2024_04_28_final.csv
    - anonymization_key.xlsx

Created files:
    - clean_and_anonymize_feedback_reading_data_output.txt
    - feedback_reading_confirmation_anonym.csv

Date: April 2024
Author: Nele Albers
"""

import pandas as pd

if __name__ == "__main__":
    
    # Name of log file
    outputfile_name = "clean_and_anonymize_feedback_reading_data_output.txt"

    # Load data
    df = pd.read_csv("Qualtrics_Exports/Human_Inv_Final_Human_Feedback_Confirmation_Final_2024_04_28_final.csv")


    # Remove Qualtrics header rows
    df = df[2:]
    df = df.reset_index(drop=True)


    # Load anonymization key
    df_key = pd.read_excel("anonymization_key.xlsx")


    # Anonymize data
    df_merged = pd.merge(df, df_key, on = "PROLIFIC_PID")
    df_merged = df_merged.drop(columns=["PROLIFIC_PID"])


    # Remove columns we cannot keep or do not need
    df_merged = df_merged.drop(columns=["PID", 
                                        "EndDate", 
                                        "Status",
                                        "Progress", 
                                        "Duration (in seconds)",
                                        "RecordedDate", 
                                        "ResponseId",
                                        "StartDate",
                                        "DistributionChannel", 
                                        "UserLanguage",
                                        "Q_RecaptchaScore",
                                        "Finished"])


    # Remove duplicates for the combination of session and rand_id
    # We keep the first recorded submission
    len_before = len(df_merged)
    df_merged = df_merged.drop_duplicates(['SESSION','rand_id'], keep='first')
    df_merged = df_merged.reset_index(drop=True)
    len_after = len(df_merged)
    print("Number of duplicates dropped:", len_before - len_after)
    with open(outputfile_name, 'w') as f:
        f.write("Number of duplicates dropped: " + str(len_before - len_after))


    df_merged.to_csv("feedback_reading_confirmation_anonym.csv", index=False)
