# RQ1: Short-term effects of human feedback on engagement


**Author**: Nele Albers

**Date**: January 2025


This file is meant to allow you to reproduce our analyses for our first research question. This includes reproducing:

   - The results regarding the direct effect of human feedback,
   - The results regarding the delayed effect of human feedback,
   - The results regarding the delayed effect of multiple feedback messages, and
   - The effort spent on activities in two previous studies without the chance of receiving human feedback and the effort spent on in-common activities in our study by people who never received feedback.


### Examine Results as Computed by Us

To examine the output of the analyses obtained by us, refer to the files:
   
   - direct_effect.pdf for the direct effect of human feedback,
   - delayed_effect_single.pdf for the delayed effect of human feedback,
   - delayed_effect_multiple.pdf for the effect of multiple feedback messages, and
   - effort_comp_across_studies_effort_with_hdi.pdf for the effort spent on activities in different studies.


### Reproduce Analyses Yourself

This section is to explain how you can run the analyses yourself.


#### Requirements

You need to have Docker installed.


#### Steps to Reproduce Analyses

The reproduction of our code is based on Docker and R Studio. Take the following steps:
1. Make sure you have Docker installed. You can check if you do by running `docker -v`.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/humaninv2024_r`, or
      - Pull the Docker image from Dockerhub via `docker pull gbna4/humaninv2024_r`.
4. Run the Docker container via `docker run -d -p 8787:8787 -v <path_to_this_directory>:/home/rstudio/analysis -e PASSWORD=<some_password> gbna4/humaninv2024_r`.
5. Go to localhost:8787.
6. Login with username 'rstudio' and the password chosen in step 4.
7. Navigate to the "analysis"-folder in R Studio.
9. Now you can reproduce the analysis results using one of the .Rmd-files mentioned earlier.


#### Knitting R Markdown

If you just want to knit an analysis file to a pdf-file, take the following steps:
1. Make sure you have Docker installed.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/humaninv2024_r`. 
      - Pull the Docker image from Dockerhub via `docker pull gbna4/humaninv2024_r`.
4. Run an interactive session with the Docker container via `docker run -it -v <path_to_directory_of_this_README_file>:/home/rstudio/analysis gbna4/humaninv2024_r /bin/bash`.
5. In the interactive session, type `cd /home/rstudio/analysis` to navigate to the analysis-folder.
6. Start an R session via `R`.
7. Import rmarkdown via `library('rmarkdown')`.
8. Knit an R markdown file via `render("<analysis_file>.Rmd", output_file = "<desired_output_file_name>.pdf")`.


### Explanation of Folders and Files

This directory contains the following files and folders:

   - Data:
      - data_rl_samples.csv: Transition samples from this study.
	  - effort_for_study_comparison_onlyneverfeedback_study2: Effort spent on activities in this study and two previous studies, using only the data on in-common activities and those people in this study who never received human feedback.
   - delayed_effect_multiple.pdf: Analysis of the delayed effect of multiple human feedback messages.
   - delayed_effect_multiple.Rmd: .Rmd-file to reproduce the analysis above.
   - delayed_effect_single.pdf: Analysis of the delayed effect of human feedback.
   - delayed_effect_single.Rmd: .Rmd-file to reproduce the analysis above.
   - direct_effect.pdf: Analysis of the direct effect of human feedback.
   - direct_effect.Rmd: .Rmd-file to reproduce the analysis above.
   - Dockerfile: To build the Docker image yourself.
   - effort_comp_across_studies_effort_with_hdi.pdf: Analysis of the effort spent in different studies.
   - effort_comp_across_studies_effort_with_hdi.Rmd: .Rmd-file to reproduce the analysis above.
   - README.md/README.pdf: This Readme-file.
